==> sharyn-4.27.1.tgz: package/redis/index.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime-corejs2/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/asyncToGenerator"));

var _bluebird = require("bluebird");

var _asyncExitHook = _interopRequireDefault(require("async-exit-hook"));

var _checkSetup = require("@sharyn/check-setup");

var _env = require("@sharyn/env");

/* eslint-disable import/no-dynamic-require, global-require */
// flow-disable-next-line
// flow-disable-next-line
// flow-disable-next-line
var Redis = (0, _checkSetup.hasPackage)('redis', true) && require("".concat(_checkSetup.appRoot, "/node_modules/redis"));

(0, _bluebird.promisifyAll)(Redis);
var DEFAULT_REDIS_URL = 'redis://localhost:8379';
var DEFAULT_TEST_REDIS_URL = 'redis://localhost:8380';
var redis = Redis.createClient(_env.NODE_ENV === 'test' ? _env.TEST_REDIS_URL || DEFAULT_TEST_REDIS_URL : _env.REDIS_URL || DEFAULT_REDIS_URL); // eslint-disable-next-line no-console

redis.on('error', function (err) {
  return console.error(err);
});
(0, _asyncExitHook.default)(
/*#__PURE__*/
function () {
  var _ref = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(callback) {
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return redis.quit();

          case 2:
            callback();

          case 3:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function (_x) {
    return _ref.apply(this, arguments);
  };
}());
module.exports = redis;

==> sharyn-11.4.0.tgz: package/redis/index.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime-corejs2/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/asyncToGenerator"));

var _bluebird = require("bluebird");

var _asyncExitHook = _interopRequireDefault(require("async-exit-hook"));

var _checkSetup = require("@sharyn/check-setup");

var _env = require("@sharyn/env");

/* eslint-disable import/no-dynamic-require, global-require */
// flow-disable-next-line
// flow-disable-next-line
// flow-disable-next-line
var Redis = (0, _checkSetup.hasPackage)('redis', true) && require("".concat(_checkSetup.appRoot, "/node_modules/redis"));

(0, _bluebird.promisifyAll)(Redis);
var DEFAULT_REDIS_URL = 'redis://localhost:8379';
var DEFAULT_TEST_REDIS_URL = 'redis://localhost:8380';
var redis = Redis.createClient(_env.NODE_ENV === 'test' ? _env.TEST_REDIS_URL || DEFAULT_TEST_REDIS_URL : _env.REDIS_URL || DEFAULT_REDIS_URL); // eslint-disable-next-line no-console

redis.on('error', function (err) {
  return console.error(err);
});
(0, _asyncExitHook["default"])(
/*#__PURE__*/
function () {
  var _ref = (0, _asyncToGenerator2["default"])(
  /*#__PURE__*/
  _regenerator["default"].mark(function _callee(callback) {
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return redis.quit();

          case 2:
            callback();

          case 3:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function (_x) {
    return _ref.apply(this, arguments);
  };
}());
module.exports = redis;
